=== modified file 'drizzled/function/math/rand.cc'
--- drizzled/function/math/rand.cc	2009-04-04 00:39:50 +0000
+++ drizzled/function/math/rand.cc	2009-12-21 04:32:56 +0000
@@ -18,10 +18,15 @@
  */
 
 #include <drizzled/server_includes.h>
-#include CSTDINT_H
 #include <drizzled/function/math/rand.h>
 #include <drizzled/session.h>
 
+static uint32_t sql_rnd()
+{
+  return (uint32_t) (rand() * 0xffffffff); /* make all bits random */
+}
+
+
 void Item_func_rand::seed_random(Item *arg)
 {
   /*

=== modified file 'drizzled/function/str/hex.cc'
--- drizzled/function/str/hex.cc	2009-04-05 17:25:57 +0000
+++ drizzled/function/str/hex.cc	2009-12-21 04:32:56 +0000
@@ -22,6 +22,19 @@
 #include CSTDINT_H
 #include <drizzled/function/str/hex.h>
 
+/**
+  convert a hex digit into number.
+*/
+static int hexchar_to_int(char c)
+{
+  if (c <= '9' && c >= '0')
+    return c-'0';
+  c|=32;
+  if (c <= 'f' && c >= 'a')
+    return c-'a'+10;
+  return -1;
+}
+
 String *Item_func_hex::val_str(String *str)
 {
   String *res;

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2009-12-21 03:44:51 +0000
+++ drizzled/server_includes.h	2009-12-21 04:32:56 +0000
@@ -142,31 +142,6 @@
 bool check_column_name(const char *name);
 bool check_table_name(const char *name, uint32_t length);
 
-/* Conversion functions */
-size_t build_tmptable_filename(char *buff, size_t bufflen);
-size_t build_table_filename(char *buff, size_t bufflen, const char *db,
-                            const char *table_name, bool is_tmp);
-
-/* Flags for conversion functions. */
-#define FN_FROM_IS_TMP  (1 << 0)
-#define FN_TO_IS_TMP    (1 << 1)
-
-inline uint32_t sql_rnd()
-{
-  return (uint32_t) (rand() * 0xffffffff); /* make all bits random */
-}
-
-/**
-  convert a hex digit into number.
-*/
-inline int hexchar_to_int(char c)
-{
-  if (c <= '9' && c >= '0')
-    return c-'0';
-  c|=32;
-  if (c <= 'f' && c >= 'a')
-    return c-'a'+10;
-  return -1;
-}
+
 
 #endif /* DRIZZLED_SERVER_INCLUDES_H */

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2009-12-04 20:16:03 +0000
+++ drizzled/sql_table.h	2009-12-21 04:32:56 +0000
@@ -37,6 +37,10 @@
 class AlterInfo;
 class Cursor;
 
+/* Flags for conversion functions. */
+static const uint32_t FN_FROM_IS_TMP(1 << 0);
+static const uint32_t FN_TO_IS_TMP(1 << 0);
+
 namespace drizzled { namespace message { class Table; } }
 namespace drizzled { class TableIdentifier; }
 
@@ -104,4 +108,10 @@
                                uint32_t *key_count,
                                int select_field_count);
 
+
+/* Conversion functions */
+size_t build_tmptable_filename(char *buff, size_t bufflen);
+size_t build_table_filename(char *buff, size_t bufflen, const char *db,
+                            const char *table_name, bool is_tmp);
+
 #endif /* DRIZZLED_SQL_TABLE_H */

